@@ -260,7 +260,7 @@ def download_user_favorites(user):
             print('Favorite n°%d' % (count))
             download_track(track)
         offset += 10
-        client.get('/users/' + str(user.id) + '/favorites', limit=10, offset=offset)
+        favorites = client.get('/users/' + str(user.id) + '/favorites', limit=10, offset=offset)
     print('All users favorites downloaded!')
 
 
@@ -312,12 +312,14 @@ def download_track(track):
             filename = filename[1:-1]
     else:
         url = stream_url.location
-        invalid_chars = '\/:*?|<>'
+        invalid_chars = '\/:*?|<>"'
         if track.user['username'] not in title and arguments["--addtofile"]:
             title = track.user['username'] + ' - ' + title
         title = ''.join(c for c in title if c not in invalid_chars)
         filename = title + '.mp3'
 
+    title = title.replace("–", "-")
+
     # Download
     if not os.path.isfile(filename):
         wget.download(url, filename)
